@@ -108,7 +108,7 @@ void AlarmModel::scheduleAlarm()
 
     // if there is an alarm that needs to rung
     if (minTime != std::numeric_limits<quint64>::max()) {
-        qDebug() << "Scheduled alarm wakeup at" << QDateTime::fromSecsSinceEpoch(minTime).toString();
+        qDebug() << "Scheduled alarm wakeup at" << QDateTime::fromSecsSinceEpoch(minTime).toString() << ".";
         m_nextAlarmTime = minTime;
 
         // if we scheduled a wakeup before, cancel it first
@@ -120,7 +120,7 @@ void AlarmModel::scheduleAlarm()
     } else {
         // this doesn't explicitly cancel the alarm currently waiting in m_worker if disabled by user
         // because alarm->ring() will return immediately if disabled
-        qDebug() << "No alarms scheduled";
+        qDebug() << "No alarms scheduled.";
 
         m_nextAlarmTime = 0;
         Utilities::instance().clearWakeup(m_cookie);
@@ -131,11 +131,11 @@ void AlarmModel::scheduleAlarm()
 
 void AlarmModel::wakeupCallback(int cookie)
 {
-    if (this->m_cookie == cookie) {
+    if (m_cookie == cookie) {
         for (auto alarm : std::as_const(alarmsToRing)) {
             alarm->ring();
         }
-        this->scheduleAlarm();
+        scheduleAlarm();
     }
 }
 void AlarmModel::removeAlarm(QString uuid)
@@ -179,7 +179,7 @@ void AlarmModel::removeAlarm(int index)
 
 void AlarmModel::addAlarm(QString name, int hours, int minutes, int daysOfWeek, QString audioPath, int ringDuration, int snoozeDuration)
 {
-    Alarm *alarm = new Alarm(this, name, hours, minutes, daysOfWeek, audioPath, ringDuration, snoozeDuration);
+    Alarm *alarm = new Alarm(name, hours, minutes, daysOfWeek, audioPath, ringDuration, snoozeDuration, this);
     alarm->save();
 
     // insert new alarm in order by time of day
